pub enum KvCacheConversionError {
SeqIdTooLarge(TryFromIntError),
P0TooLarge(TryFromIntError),
P1TooLarge(TryFromIntError),
UnsupportedOperation(String),
}Expand description
Errors that can occur when attempting to prepare values for the kv cache
Variants
SeqIdTooLarge(TryFromIntError)
Sequence id conversion to i32 failed
P0TooLarge(TryFromIntError)
Position 0 conversion to i32 failed
P1TooLarge(TryFromIntError)
Position 1 conversion to i32 failed
UnsupportedOperation(String)
The operation is not supported by the current model/context configuration.