Module error

Module error 

Enums

ApplyChatTemplateError
Failed to apply model chat template.
ChatParseError
Failed to parse a chat response.
ChatTemplateError
There was an error while getting the chat template from a model.
DecodeError
Failed to decode a batch.
EmbeddingsError
When embedding related functions fail
EncodeError
Failed to decode a batch.
GrammarError
Errors that can occur when initializing a grammar sampler
LlamaContextLoadError
Failed to Load context
LlamaCppError
All errors that can occur in the llama-cpp crate.
LlamaLoraAdapterInitError
An error that can occur when loading a model.
LlamaLoraAdapterRemoveError
An error that can occur when loading a model.
LlamaLoraAdapterSetError
An error that can occur when loading a model.
LlamaModelLoadError
An error that can occur when loading a model.
LogitsError
When logits-related functions fail
MetaValError
Failed fetching metadata value
ModelParamsError
Errors that can occur when modifying model parameters.
NewLlamaChatMessageError
Failed to apply model chat template.
SampleError
Errors that can occur when sampling a token.
SamplerAcceptError
Failed to accept a token in a sampler.
SamplingError
Errors that can occur when creating a sampling configuration.
StringToTokenError
Failed to convert a string to a token sequence.
TokenSamplingError
Failed to sample a token from the data array.
TokenToStringError
An error that can occur when converting a token to a string.

Type Aliases

Result
A failable result from a llama.cpp function.