pub enum EvalMultimodalChunksError {
EvalFailed(MtmdEvalError),
UnknownChunkType(MtmdInputChunkTypeError),
ChunkOutOfBounds(usize),
}Expand description
Failed to evaluate multimodal chunks through the request classifier.
Variants
EvalFailed(MtmdEvalError)
MtmdInputChunks::eval_chunks returned an error.
UnknownChunkType(MtmdInputChunkTypeError)
A chunk reported a type that is not known to this binding.
ChunkOutOfBounds(usize)
A chunk index that was within chunks.len() returned None from chunks.get(index).