pub enum GrammarError {
RootNotFound,
TriggerWordNullBytes(NulError),
GrammarNullBytes(NulError),
NulError(NulError),
NullGrammar(String),
IntegerOverflow(String),
LlguidanceError(String),
}Expand description
Errors that can occur when initializing a grammar sampler
Variants
RootNotFound
The grammar root was not found in the grammar string
TriggerWordNullBytes(NulError)
The trigger word contains null bytes
GrammarNullBytes(NulError)
The grammar string or root contains null bytes
NulError(NulError)
A string contains null bytes
NullGrammar(String)
The grammar call returned null
IntegerOverflow(String)
An integer value exceeded the allowed range
LlguidanceError(String)
An error from the llguidance library