pub enum LogitsError {
NullLogits,
TokenNotInitialized(i32),
TokenIndexExceedsContext {
token_index: u32,
context_size: u32,
},
VocabSizeOverflow(TryFromIntError),
TokenIndexOverflow(TryFromIntError),
}Expand description
When logits-related functions fail
Variants
NullLogits
The logits data pointer is null.
TokenNotInitialized(i32)
The requested token index has not been initialized for logits.
TokenIndexExceedsContext
The token index exceeds the context size.
VocabSizeOverflow(TryFromIntError)
The vocabulary size does not fit into a usize.
TokenIndexOverflow(TryFromIntError)
The token index does not fit into a u32.