pub enum AddBos {
Always,
Never,
}Expand description
How to determine if we should prepend a bos token to tokens
Variants
Always
Add the beginning of stream token to the start of the string.
Never
Do not add the beginning of stream token to the start of the string.