mtmd_default_marker

Function mtmd_default_marker 

pub fn mtmd_default_marker() -> &'static str
Get the default media marker string.

Returns the default marker used to identify media positions in text (typically "<__media__>"). This marker should be used in your input text to indicate where media content should be inserted.

Examples

use llama_cpp_bindings::mtmd::mtmd_default_marker;

let marker = mtmd_default_marker();
assert!(!marker.is_empty());

let text = format!("Describe this image: {}", marker);
assert!(text.contains(marker));