pub enum GrammarSamplerError {
MissingTriggers,
TriggerWordNotPreserved(String),
TokenizationFailed(String),
GrammarInitFailed(GrammarError),
}Expand description
Error type for grammar sampler construction.
Variants
MissingTriggers
Lazy grammar mode is enabled but no triggers were provided.
TriggerWordNotPreserved(String)
A trigger word is not in the preserved tokens set.
TokenizationFailed(String)
Failed to tokenize a trigger or preserved token.
GrammarInitFailed(GrammarError)
Failed to initialize the grammar sampler.