Enums
- Apply
Chat Template Error - Failed to apply model chat template.
- Chat
Parse Error - Failed to parse a chat response.
- Chat
Template Error - There was an error while getting the chat template from a model.
- Decode
Error - Failed to decode a batch.
- Embeddings
Error - When embedding related functions fail
- Encode
Error - Failed to decode a batch.
- Grammar
Error - Errors that can occur when initializing a grammar sampler
- Llama
Context Load Error - Failed to Load context
- Llama
CppError - All errors that can occur in the llama-cpp crate.
- Llama
Lora Adapter Init Error - An error that can occur when loading a model.
- Llama
Lora Adapter Remove Error - An error that can occur when loading a model.
- Llama
Lora Adapter SetError - An error that can occur when loading a model.
- Llama
Model Load Error - An error that can occur when loading a model.
- Logits
Error - When logits-related functions fail
- Meta
ValError - Failed fetching metadata value
- Model
Params Error - Errors that can occur when modifying model parameters.
- NewLlama
Chat Message Error - Failed to apply model chat template.
- Sample
Error - Errors that can occur when sampling a token.
- Sampler
Accept Error - Failed to accept a token in a sampler.
- Sampling
Error - Errors that can occur when creating a sampling configuration.
- String
ToToken Error - Failed to convert a string to a token sequence.
- Token
Sampling Error - Failed to sample a token from the data array.
- Token
ToString Error - An error that can occur when converting a token to a string.
Type Aliases
- Result
- A failable result from a llama.cpp function.