Module error

Module error 

Enums

ApplyChatTemplateError
Failed to apply model chat template.
BracketedArgsFailure
Failures specific to the bracketed-JSON args parser (Mistral 3 [TOOL_CALLS]name[ARGS]{...}).
ChatTemplateError
There was an error while getting the chat template from a model.
DecodeError
Failed to decode a batch.
EmbeddingsError
When embedding related functions fail
EncodeError
Failed to decode a batch.
EvalMultimodalChunksError
Failed to evaluate multimodal chunks through the request classifier.
FitError
Returned by crate::model::params::LlamaModelParams::fit_params.
GrammarError
Errors that can occur when initializing a grammar sampler
JsonObjectFailure
Failures specific to the JSON-object args parser (Qwen 3 <tool_call>{"name":..., "arguments":...}</tool_call>).
KeyValueXmlTagsFailure
Failures specific to the key-value XML-tags parser (GLM-4.7 <tool_call>{name}<arg_key>{k}</arg_key><arg_value>{v}</arg_value>...</tool_call>).
LlamaContextLoadError
Failed to Load context
LlamaCppError
All errors that can occur in the llama-cpp crate.
LlamaLoraAdapterInitError
An error that can occur when loading a model.
LlamaLoraAdapterRemoveError
An error that can occur when loading a model.
LlamaLoraAdapterSetError
An error that can occur when loading a model.
LlamaModelLoadError
An error that can occur when loading a model.
LogitsError
When logits-related functions fail
MarkerDetectionError
Failed to detect tool-call diagnostic markers for a model.
MetaValError
Failed fetching metadata value
ModelParamsError
Errors that can occur when modifying model parameters.
NewLlamaChatMessageError
Failed to apply model chat template.
PairedQuoteFailure
Failures specific to the paired-quote args parser (Gemma 4 <|tool_call>call:name{key:<|"|>val<|"|>}).
ParseChatMessageError
Failed to parse a chat message via [crate::Model::parse_chat_message].
SampleError
Errors that can occur when sampling a token.
SamplerAcceptError
Failed to accept a token in a sampler.
SamplingError
Errors that can occur when creating a sampling configuration.
StringToTokenError
Failed to convert a string to a token sequence.
TokenSamplingError
Failed to sample a token from the data array.
TokenToStringError
An error that can occur when converting a token to a string.
ToolCallFormatFailure
Top-level failure for the wrapper-side template-override parsers (one variant per supported shape).
XmlFunctionTagsFailure
Failures specific to the XML function-tags parser (Qwen 3.5+ <function=name><parameter=key>val</parameter></function>).

Type Aliases

Result
A failable result from a llama.cpp function.