Enums
- Apply
Chat Template Error - Failed to apply model chat template.
- Bracketed
Args Failure - Failures specific to the bracketed-JSON args parser (Mistral 3
[TOOL_CALLS]name[ARGS]{...}). - Chat
Template Error - There was an error while getting the chat template from a model.
- Decode
Error - Failed to decode a batch.
- Embeddings
Error - When embedding related functions fail
- Encode
Error - Failed to decode a batch.
- Eval
Multimodal Chunks Error - Failed to evaluate multimodal chunks through the request classifier.
- FitError
- Returned by
crate::model::params::LlamaModelParams::fit_params. - Grammar
Error - Errors that can occur when initializing a grammar sampler
- Json
Object Failure - Failures specific to the JSON-object args parser (Qwen 3
<tool_call>{"name":..., "arguments":...}</tool_call>). - KeyValue
XmlTags Failure - Failures specific to the key-value XML-tags parser (GLM-4.7
<tool_call>{name}<arg_key>{k}</arg_key><arg_value>{v}</arg_value>...</tool_call>). - Llama
Context Load Error - Failed to Load context
- Llama
CppError - All errors that can occur in the llama-cpp crate.
- Llama
Lora Adapter Init Error - An error that can occur when loading a model.
- Llama
Lora Adapter Remove Error - An error that can occur when loading a model.
- Llama
Lora Adapter SetError - An error that can occur when loading a model.
- Llama
Model Load Error - An error that can occur when loading a model.
- Logits
Error - When logits-related functions fail
- Marker
Detection Error - Failed to detect tool-call diagnostic markers for a model.
- Meta
ValError - Failed fetching metadata value
- Model
Params Error - Errors that can occur when modifying model parameters.
- NewLlama
Chat Message Error - Failed to apply model chat template.
- Paired
Quote Failure - Failures specific to the paired-quote args parser (Gemma 4
<|tool_call>call:name{key:<|"|>val<|"|>}). - Parse
Chat Message Error - Failed to parse a chat message via [
crate::Model::parse_chat_message]. - Sample
Error - Errors that can occur when sampling a token.
- Sampler
Accept Error - Failed to accept a token in a sampler.
- Sampling
Error - Errors that can occur when creating a sampling configuration.
- String
ToToken Error - Failed to convert a string to a token sequence.
- Token
Sampling Error - Failed to sample a token from the data array.
- Token
ToString Error - An error that can occur when converting a token to a string.
- Tool
Call Format Failure - Top-level failure for the wrapper-side template-override parsers (one variant per supported shape).
- XmlFunction
Tags Failure - Failures specific to the XML function-tags parser (Qwen 3.5+
<function=name><parameter=key>val</parameter></function>).
Type Aliases
- Result
- A failable result from a llama.cpp function.