pub struct LlamaBatch<'tokens> {
pub initialized_logits: Vec<i32>,
pub llama_batch: llama_batch,
/* private fields */
}Fields
initialized_logits: Vec<i32>llama_batch: llama_batchImplementations
Sourceimpl<'tokens> LlamaBatch<'tokens>
impl<'tokens> LlamaBatch<'tokens>
pub fn clear(&mut self)
Sourcepub fn add(
&mut self,
sampled_token: &SampledToken,
pos: llama_pos,
seq_ids: &[i32],
logits: bool,
) -> Result<(), BatchAddError>
pub fn add( &mut self, sampled_token: &SampledToken, pos: llama_pos, seq_ids: &[i32], logits: bool, ) -> Result<(), BatchAddError>
Errors
Returns an error if there is insufficient space in the buffer or if integer conversions fail.
Sourcepub fn add_sequence(
&mut self,
tokens: &[LlamaToken],
seq_id: i32,
logits_all: bool,
) -> Result<(), BatchAddError>
pub fn add_sequence( &mut self, tokens: &[LlamaToken], seq_id: i32, logits_all: bool, ) -> Result<(), BatchAddError>
Errors
Returns an error if there is insufficient space in the buffer or if integer conversions fail.
Sourcepub fn new(n_tokens: usize, n_seq_max: i32) -> Result<Self, BatchAddError>
pub fn new(n_tokens: usize, n_seq_max: i32) -> Result<Self, BatchAddError>
Errors
Returns an error if n_tokens exceeds i32::MAX.
Sourcepub fn get_one(tokens: &'tokens [LlamaToken]) -> Result<Self, BatchAddError>
pub fn get_one(tokens: &'tokens [LlamaToken]) -> Result<Self, BatchAddError>
Errors
Returns an error if the provided token buffer is empty or if integer conversions fail.
pub const fn n_tokens(&self) -> i32