pub struct MtmdContext {
pub context: NonNull<mtmd_context>,
}Expand description
Safe wrapper around mtmd_context.
This represents an initialized multimodal context that can process text, images, and audio through llama.cpp’s multimodal interface.
Fields
context: NonNull<mtmd_context>Raw pointer to the underlying mtmd_context.
Implementations
Sourceimpl MtmdContext
impl MtmdContext
Sourcepub fn init_from_file(
mmproj_path: &str,
text_model: &LlamaModel,
params: &MtmdContextParams,
) -> Result<Self, MtmdInitError>
pub fn init_from_file( mmproj_path: &str, text_model: &LlamaModel, params: &MtmdContextParams, ) -> Result<Self, MtmdInitError>
Initialize MTMD context from a multimodal projection file.
Errors
Returns an MtmdInitError variant matching the wrapper’s status code.
Sourcepub fn decode_use_non_causal(&self, chunk: &MtmdInputChunk) -> bool
pub fn decode_use_non_causal(&self, chunk: &MtmdInputChunk) -> bool
Check whether non-causal attention mask is needed before llama_decode
for the given input chunk.
Sourcepub fn decode_use_mrope(&self) -> bool
pub fn decode_use_mrope(&self) -> bool
Check whether the current model uses M-RoPE for llama_decode.
Sourcepub fn support_vision(&self) -> bool
pub fn support_vision(&self) -> bool
Check whether the current model supports vision input.
Sourcepub fn support_audio(&self) -> bool
pub fn support_audio(&self) -> bool
Check whether the current model supports audio input.
Sourcepub fn get_audio_sample_rate(&self) -> Option<u32>
pub fn get_audio_sample_rate(&self) -> Option<u32>
Get audio sample rate in Hz (e.g., 16000 for Whisper). Returns None if audio is not supported.
Sourcepub fn tokenize(
&self,
text: MtmdInputText,
bitmaps: &[&MtmdBitmap],
) -> Result<MtmdInputChunks, MtmdTokenizeError>
pub fn tokenize( &self, text: MtmdInputText, bitmaps: &[&MtmdBitmap], ) -> Result<MtmdInputChunks, MtmdTokenizeError>
Tokenize input text and bitmaps into chunks.
The input text must contain media markers (default: <__media__>) that will be
replaced with the corresponding bitmap data from the bitmaps array.
The number of bitmaps must equal the number of markers in the text.
Errors
Returns an MtmdTokenizeError variant matching the wrapper’s status code.
Sourcepub fn encode_chunk(
&self,
chunk: &MtmdInputChunk,
) -> Result<(), MtmdEncodeError>
pub fn encode_chunk( &self, chunk: &MtmdInputChunk, ) -> Result<(), MtmdEncodeError>
Encode a chunk for image/audio processing.
Errors
Returns an MtmdEncodeError variant matching the wrapper’s status code.